@@ -14,6 +14,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 
+import atexit
 import logging
 import os
 import shlex
@@ -219,8 +220,8 @@ args_dict = {
         "--disk path=%(EXISTIMG1)s,device=floppy",
         # Existing disk, no extra options
         "--disk path=%(EXISTIMG1)s",
-        # Create volume in a pool
-        "--disk pool=%(POOL)s,size=.0001",
+        # Create 2 volumes in a pool
+        "--disk pool=%(POOL)s,size=.0001 --disk pool=%(POOL)s,size=.0001",
         # Existing volume
         "--disk vol=%(POOL)s/%(VOL)s",
         # 3 IDE and CD
@@ -251,8 +252,6 @@ args_dict = {
         "--disk %(DIR)s,device=floppy",
         # Driver name and type options
         "--disk %(EXISTIMG1)s,driver_name=qemu,driver_type=qcow2",
-        # Unknown driver name and type options
-        "--disk %(EXISTIMG1)s,driver_name=foobar,driver_type=foobaz",
         # Using a storage pool source as a disk
         "--disk /dev/hda",
         # Building 'default' pool
@@ -290,6 +289,8 @@ args_dict = {
         "--disk %(COLLIDE)s",
         # Dir without floppy
         "--disk %(DIR)s,device=cdrom",
+        # Unknown driver name and type options (as of 1.0.0)
+        "--disk %(EXISTIMG1)s,driver_name=foobar,driver_type=foobaz",
       ]
      }, # category "storage"
 
@@ -675,6 +676,7 @@ args_dict = {
         "--controller usb,model=ich9-ehci1,address=0:0:4.7",
         "--controller usb,model=ich9-ehci1,address=0:0:4.7,index=0",
         "--controller usb,model=ich9-ehci1,address=0:0:4.7,index=1,master=0",
+        "--controller usb2",
       ],
 
       "invalid": [
@@ -1434,3 +1436,5 @@ _cmdlist = build_cmd_list()
 for _cmd in _cmdlist:
     newidx += 1
     setattr(CLITests, "testCLI%d" % newidx, maketest(_cmd))
+
+atexit.register(cleanup)
