@@ -235,7 +235,6 @@ def get_virt_type(conn, options):
 
     capabilities = virtinst.CapabilitiesParser.parse(conn.getCapabilities())
 
-    # Accelerate request is now the default
     req_accel = True
     req_hv_type = options.hv_type and options.hv_type.lower() or None
     if options.fullvirt:
@@ -276,6 +275,7 @@ def get_virt_type(conn, options):
         fail(e)
 
     if (not req_virt_type and
+        not req_hv_type and
         req_accel and
         _util.is_qemu(conn) and
         capsguest.arch in ["i686", "x86_64"] and
@@ -393,7 +393,7 @@ def check_option_collisions(options, guest):
         if options.mac:
             fail(_("Cannot use --mac with --nonetworks"))
         if options.bridge:
-            fail(_("Cannot use --bridges with --nonetworks"))
+            fail(_("Cannot use --bridge with --nonetworks"))
         if options.network:
             fail(_("Cannot use --network with --nonetworks"))
         return
@@ -656,14 +656,13 @@ def start_install(guest, continue_inst, options):
             dom.create()
             guest.connect_console(conscb)
 
-    except KeyboardInterrupt, e:
+    except KeyboardInterrupt:
         logging.debug("", exc_info=True)
         guest.terminate_console()
         print_stderr(_("Domain install interrupted."))
+        raise
     except RuntimeError, e:
         fail(e)
-    except SystemExit, e:
-        sys.exit(e.code)
     except Exception, e:
         fail(e, do_exit=False)
         cli.install_fail(guest)
@@ -866,7 +865,7 @@ def parse_args():
         help=_("Specify storage with various options. Ex.\n"
                "--disk path=/my/existing/disk\n"
                "--disk path=/my/new/disk,size=5 (in gigabytes)\n"
-               "--disk vol=poolname:volname,device=cdrom,bus=scsi,..."))
+               "--disk vol=poolname/volname,device=cdrom,bus=scsi,..."))
     stog.add_option("", "--nodisks", action="store_true",
                     help=_("Don't set up any disks for the guest."))
     cli.add_fs_option(stog)
