@@ -31,6 +31,7 @@ from virtinst import VirtualVideoDevice
 from virtinst import VirtualController
 from virtinst import VirtualWatchdog
 from virtinst import VirtualInputDevice
+from virtinst import VirtualMemballoon
 import utils
 
 _testconn = utils.open_testdriver()
@@ -586,7 +587,7 @@ class TestXMLConfig(unittest.TestCase):
         g = utils.get_basic_fullyvirt_guest(installer=i)
 
         net1 = VirtualNetworkInterface(type="user",
-                                       macaddr="11:11:11:11:11:11")
+                                       macaddr="22:11:11:11:11:11")
         net2 = utils.get_virtual_network()
         net3 = utils.get_virtual_network()
         net3.model = "e1000"
@@ -714,6 +715,7 @@ class TestXMLConfig(unittest.TestCase):
         g.disks.append(VirtualDisk(conn=g.conn, path="/tmp", device="floppy"))
         d3 = VirtualDisk(conn=g.conn, path="/default-pool/testvol1.img",
                          bus="scsi", driverName="qemu")
+        d3.address.type = "spapr-vio"
         g.disks.append(d3)
 
         # Controller devices
@@ -729,9 +731,14 @@ class TestXMLConfig(unittest.TestCase):
         net1 = utils.get_virtual_network()
         net1.model = "e1000"
         net2 = VirtualNetworkInterface(type="user",
-                                       macaddr="11:11:11:11:11:11")
+                                       macaddr="22:11:11:11:11:11")
+        net3 = VirtualNetworkInterface(type=virtinst.VirtualNetworkInterface.TYPE_VIRTUAL,
+                                       macaddr="22:22:22:22:22:22", network="default")
+        net3.model = "spapr-vlan"
+        net3.set_address("spapr-vio")
         g.nics.append(net1)
         g.nics.append(net2)
+        g.nics.append(net3)
 
         # Character devices
         cdev1 = VirtualCharDevice.get_dev_instance(g.conn,
@@ -766,11 +773,17 @@ class TestXMLConfig(unittest.TestCase):
         g.add_device(vdev3)
         g.add_device(vdev4)
 
+        # Watchdog Devices
         wdev2 = VirtualWatchdog(g.conn)
         wdev2.model = "ib700"
         wdev2.action = "none"
         g.add_device(wdev2)
 
+        # Memballoon Devices
+        mdev1 = VirtualMemballoon(g.conn)
+        mdev1.model = "virtio"
+        g.add_device(mdev1)
+
         # Check keymap autoconfig
         gdev1 = virtinst.VirtualGraphics(conn=g.conn, type="vnc")
         self.assertTrue(gdev1.keymap != None)
@@ -782,6 +795,7 @@ class TestXMLConfig(unittest.TestCase):
 
         gdev3 = virtinst.VirtualGraphics(conn=g.conn, type="sdl")
         gdev4 = virtinst.VirtualGraphics(conn=g.conn, type="spice")
+        gdev4.passwdValidTo = "foobar"
 
         gdev5 = virtinst.VirtualGraphics(conn=g.conn, type="sdl")
         gdev5.xauth = "fooxauth"
@@ -921,20 +935,20 @@ class TestXMLConfig(unittest.TestCase):
             util.default_bridge2 = newbridge
 
             dev1 = virtinst.VirtualNetworkInterface(conn=g.conn)
-            dev1.macaddr = "11:22:33:44:55:66"
+            dev1.macaddr = "22:22:33:44:55:66"
             g.add_device(dev1)
 
             dev2 = virtinst.VirtualNetworkInterface(conn=g.conn,
                                                 parsexml=dev1.get_xml_config())
             dev2.source = None
             dev2.source = "foobr0"
-            dev2.macaddr = "11:22:33:44:55:67"
+            dev2.macaddr = "22:22:33:44:55:67"
             g.add_device(dev2)
 
             dev3 = virtinst.VirtualNetworkInterface(conn=g.conn,
                                                 parsexml=dev1.get_xml_config())
             dev3.source = None
-            dev3.macaddr = "11:22:33:44:55:68"
+            dev3.macaddr = "22:22:33:44:55:68"
             g.add_device(dev3)
 
             self._compare(g, "boot-default-bridge", False, do_create=False)
@@ -975,5 +989,12 @@ class TestXMLConfig(unittest.TestCase):
         self.assertEquals("vdaa", targetlist[26])
         self.assertEquals("vdba", targetlist[26 * 2])
 
+    def testFedoraTreeinfo(self):
+        i = utils.make_distro_installer(
+                                location="tests/cli-test-xml/fakefedoratree",
+                                gtype="kvm")
+        t, v = i.detect_distro()
+        self.assertEquals((t, v), ("linux", "fedora17"))
+
 if __name__ == "__main__":
     unittest.main()
