@@ -21,15 +21,20 @@
 import pkgutil
 import imp
 import os
+import sys
 import gettext
 
-gettext_dir = "::LOCALEDIR::"
-gettext_app = "virtinst"
+gettext.bindtextdomain("virtinst")
+_gettext = lambda m: gettext.dgettext("virtinst", m)
 
-gettext.bindtextdomain(gettext_app, gettext_dir)
-
-def _gettext(msg):
-    return gettext.dgettext(gettext_app, msg)
+try:
+    import _config
+except ImportError:
+    print "virtconv: Please run 'python setup.py build' in the source"
+    print "          directory before using the code."
+    sys.exit(1)
+__version__ = _config.__version__
+__version_info__ = _config.__version_info__
 
 parsers_path = [os.path.join(__path__[0], "parsers/")]
 
