@@ -1,7 +1,7 @@
 #
 # Some code for parsing libvirt's capabilities XML
 #
-# Copyright 2007  Red Hat, Inc.
+# Copyright 2007, 2012  Red Hat, Inc.
 # Mark McLoughlin <markmc@redhat.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 
 import re
 
-from virtinst import _virtinst as _
+from virtinst import _gettext as _
 import _util
 
 class CapabilitiesParserException(Exception):
@@ -260,11 +260,15 @@ class Host(object):
     def __init__(self, node=None):
         self.cpu = CPU()
         self.topology = None
-        self.secmodel = None
+        self.secmodels = []
 
         if not node is None:
             self.parseXML(node)
 
+    def get_secmodel(self):
+        return self.secmodels and self.secmodels[0] or None
+    secmodel = property(get_secmodel)
+
     # Back compat for CPU class
     def get_arch(self):
         return self.cpu.arch
@@ -285,7 +289,7 @@ class Host(object):
                 self.topology = Topology(child)
 
             if child.name == "secmodel":
-                self.secmodel = SecurityModel(child)
+                self.secmodels.append(SecurityModel(child))
 
             if child.name == "cpu":
                 self.cpu = CPU(child)
@@ -585,9 +589,9 @@ class Capabilities(object):
         Try to determine if fullvirt may be disabled in the bios.
 
         Check is basically:
-        - We support HW virt
-        - We appear to be xen
-        - There are no HVM install options
+            - We support HW virt
+            - We appear to be xen
+            - There are no HVM install options
 
         We don't do this check for KVM, since no KVM options may mean
         KVM isn't installed or the module isn't loaded (and loading the
@@ -688,9 +692,9 @@ def guest_lookup(conn, caps=None, os_type=None, arch=None, type=None,
     we return the default virt type associated with those values. These are
     typically:
 
-    - os_type    : hvm, then xen
-    - type : kvm over plain qemu
-    - arch    : host arch over all others
+        - os_type    : hvm, then xen
+        - type : kvm over plain qemu
+        - arch    : host arch over all others
 
     Otherwise the default will be the first listed in the capabilities xml.
     This function throws C{ValueError}s if any of the requested values are
@@ -699,7 +703,7 @@ def guest_lookup(conn, caps=None, os_type=None, arch=None, type=None,
     @param conn: virConnect instance
     @type conn: libvirt.virConnect
     @param caps: Optional L{Capabilities} instance (saves a lookup)
-    @type conn: L{Capabilities}
+    @type caps: L{Capabilities}
     @param type: Virtualization type ('hvm', 'xen', ...)
     @type type: C{str}
     @param arch: Guest architecture ('x86_64', 'i686' ...)
