@@ -17,13 +17,18 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 
-class Clock(object):
+import XMLBuilderDomain
+from XMLBuilderDomain import _xml_property
+
+class Clock(XMLBuilderDomain.XMLBuilderDomain):
     """
     Class for generating <clock> XML
     """
 
-    def __init__(self, conn):
-        self.conn = conn
+    _dumpxml_xpath = "/domain/clock"
+    def __init__(self, conn, parsexml=None, parsexmlnode=None, caps=None):
+        XMLBuilderDomain.XMLBuilderDomain.__init__(self, conn, parsexml,
+                                                   parsexmlnode, caps)
 
         self._offset = None
 
@@ -31,9 +36,10 @@ class Clock(object):
         return self._offset
     def set_offset(self, val):
         self._offset = val
-    offset = property(get_offset, set_offset)
+    offset = _xml_property(get_offset, set_offset,
+                           xpath="./clock/@offset")
 
-    def get_xml_config(self):
+    def _get_xml_config(self):
         if not self.offset:
             return ""
 
