@@ -1,4 +1,5 @@
 #
+# Copyright 2013  Red Hat, Inc.
 # Copyright(c) FUJITSU Limited 2007.
 #
 # Cloning a virtual machine module.
@@ -404,6 +405,7 @@ class CloneDesign(object):
 
         self._guest = Guest.Guest(conn=self._hyper_conn,
                                   parsexml=self.original_xml)
+        self._guest.replace = self.replace
 
         # Pull clonable storage info from the original xml
         self._original_virtual_disks = self._get_original_devices_info()
@@ -473,10 +475,22 @@ class CloneDesign(object):
                     xmldisk = disk
 
             if clone_disk.vol_object:
-                # XXX We could do this with vol upload I think
-                raise RuntimeError(
-                    _("Clone onto existing storage volume is not "
-                      "supported: '%s'") % clone_disk.path)
+                # XXX We could always do this with vol upload?
+
+                # Special case: non remote cloning of a guest using
+                # managed block devices: fall back to local cloning if
+                # we have permissions to do so. This validation check
+                # caused a few bug reports in a short period of time,
+                # so must be a common case.
+                if (clone_disk.is_remote() or
+                    clone_disk.type != clone_disk.TYPE_BLOCK or
+                    not orig_disk.path or
+                    not os.access(orig_disk.path, os.R_OK) or
+                    not clone_disk.path or
+                    not os.access(clone_disk.path, os.W_OK)):
+                    raise RuntimeError(
+                        _("Clone onto existing storage volume is not "
+                          "currently supported: '%s'") % clone_disk.path)
 
             # Sync 'size' between the two
             if orig_disk.size:
