@@ -782,7 +782,8 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
             "controller": virtinst.VirtualController,
             "filesystem": virtinst.VirtualFilesystem,
             "smartcard" : virtinst.VirtualSmartCardDevice,
-            "redirdev"   : virtinst.VirtualRedirDevice,
+            "redirdev"  : virtinst.VirtualRedirDevice,
+            "memballoon": virtinst.VirtualMemballoon,
         }
 
         # Hand off all child element parsing to relevant classes
@@ -870,11 +871,20 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
             finally:
                 if origpath:
                     dev.path = origpath
+        def get_vscsi_ctrl_xml():
+            vscsi_class = virtinst.VirtualController.get_class_for_type(
+                          virtinst.VirtualController.CONTROLLER_TYPE_SCSI)
+            ctrl = vscsi_class(self.conn)
+            ctrl.set_address("spapr-vio")
+            return ctrl.get_xml_config()
 
         xml = self._get_emulator_xml()
         # Build XML
         for dev in devs:
             xml = _util.xml_append(xml, get_dev_xml(dev))
+            if (dev.address.type == "spapr-vio" and
+                  dev.virtual_device_type == virtinst.VirtualDevice.VIRTUAL_DEV_DISK):
+                xml = _util.xml_append(xml, get_vscsi_ctrl_xml())
 
         return xml
 
@@ -1425,6 +1435,9 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
         if features["pae"] is None and self._get_caps():
             features["pae"] = self._get_caps().support_pae()
 
+        if (self.installer.machine == None and
+            self._get_caps().host.arch == "ppc64"):
+            self.installer.machine = "pseries"
 
     def _set_pv_defaults(self, devlist_func, remove_func):
         # Default file backed PV guests to tap driver
@@ -1493,10 +1506,17 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
                     disk.bus = "fdc"
                 else:
                     if self.installer.is_hvm():
-                        disk.bus = "ide"
+                        if (self.installer.type == "kvm" and
+                            self.installer.machine == "pseries"):
+                            disk.bus = "scsi"
+                        else:
+                            disk.bus = "ide"
                     elif self.installer.is_xenpv():
                         disk.bus = "xen"
-            used_targets.append(disk.generate_target(used_targets))
+            if disk.target:
+                used_targets.append(disk.target)
+            else:
+                used_targets.append(disk.generate_target(used_targets))
 
         # Set sound device model
         sound_model  = self._lookup_device_param(soundtype, "model")
@@ -1536,16 +1556,7 @@ class Guest(XMLBuilderDomain.XMLBuilderDomain):
 
         # Generate UUID
         if self.uuid is None:
-            found = False
-            for ignore in range(256):
-                self.uuid = _util.uuidToString(_util.randomUUID())
-                if _util.vm_uuid_collision(self.conn, self.uuid):
-                    continue
-                found = True
-                break
-
-            if not found:
-                logging.debug("Failed to generate non-conflicting UUID")
+            self.uuid = _util.generate_uuid(self.conn)
 
 
     ###################################
