@@ -1,7 +1,7 @@
 # Sample code to parse an image XML description and
 # spit out libvirt XML; will be hooked into virt-install
 #
-# Copyright 2007  Red Hat, Inc.
+# Copyright 2007, 2013  Red Hat, Inc.
 # David Lutterkort <dlutter@redhat.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,12 +19,16 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 
-import os.path
-import libxml2
-import CapabilitiesParser
-from virtinst import _virtinst as _
-import _util
 import logging
+import os
+
+import libxml2
+import urlgrabber
+
+import CapabilitiesParser
+from virtinst import _gettext as _
+import _util
+
 
 class ParserException(Exception):
     def __init__(self, msg):
@@ -42,7 +46,7 @@ class Image:
         if base is None:
             if filename is not None:
                 self.base = os.path.dirname(filename)
-                if self.base == '' :
+                if self.base == '':
                     self.base = "."
             else:
                 self.base = "."
@@ -201,6 +205,7 @@ class Disk:
     FORMAT_QCOW = "qcow"
     FORMAT_QCOW2 = "qcow2"
     FORMAT_VMDK = "vmdk"
+    FORMAT_VDI = "vdi"
 
     USE_SYSTEM = "system"
     USE_USER = "user"
@@ -227,7 +232,12 @@ class Disk:
             csumtype = xpathString(d, "@type")
             csumvalue = xpathString(d, "")
             self.csum[csumtype] = csumvalue
-        formats = [Disk.FORMAT_RAW, Disk.FORMAT_QCOW, Disk.FORMAT_QCOW2, Disk.FORMAT_VMDK, Disk.FORMAT_ISO]
+        formats = [Disk.FORMAT_RAW,
+                   Disk.FORMAT_QCOW,
+                   Disk.FORMAT_QCOW2,
+                   Disk.FORMAT_VMDK,
+                   Disk.FORMAT_ISO,
+                   Disk.FORMAT_VDI]
         validate(formats.count(self.format) > 0,
                  _("The format for disk %s must be one of %s") %
                  (self.file, ",".join(formats)))
@@ -240,6 +250,9 @@ class Disk:
             import sha
             hashlib = None
 
+        if meter is None:
+            meter = urlgrabber.progress.BaseMeter()
+
         m = None
         if hashlib:
             if "sha256" in self.csum:
@@ -259,18 +272,16 @@ class Disk:
 
         meter_ct = 0
         disk_size = os.path.getsize(self.file)
-        if meter:
-            meter.start(size=disk_size,
-                        text=_("Checking disk signature for %s" % self.file))
+        meter.start(size=disk_size,
+                    text=_("Checking disk signature for %s" % self.file))
 
         f = file(self.file)
         while 1:
             chunk = f.read(65536)
             if not chunk:
                 break
-            if meter:
-                meter.update(meter_ct)
-                meter_ct = meter_ct + 65536
+            meter.update(meter_ct)
+            meter_ct = meter_ct + 65536
             m.update(chunk)
         checksum = m.hexdigest()
         if checksum != csumvalue:
