@@ -419,9 +419,9 @@ class Installer(XMLBuilderDomain.XMLBuilderDomain):
         """
         Fetch any files needed for installation.
         @param guest: guest instance being installed
-        @type L{Guest}
+        @type guest: L{Guest}
         @param meter: progress meter
-        @type Urlgrabber ProgressMeter
+        @type meter: Urlgrabber ProgressMeter
         """
         raise NotImplementedError("Must be implemented in subclass")
 
@@ -432,7 +432,7 @@ class Installer(XMLBuilderDomain.XMLBuilderDomain):
         @type L{Guest}
         """
 
-        if _util.is_uri_remote(guest.conn.getURI()):
+        if _util.is_uri_remote(guest.conn.getURI(), conn=guest.conn):
             # XXX: Use block peek for this?
             return True
 
