@@ -240,6 +240,7 @@ class Distro:
     _hvm_kernel_paths = []
     _xen_kernel_paths = []
     uses_treeinfo = False
+    method_arg = "method"
 
     def __init__(self, uri, arch, vmtype=None, scratchdir=None):
         self.uri = uri
@@ -373,7 +374,7 @@ class Distro:
         args = ''
 
         if not fetcher.location.startswith("/"):
-            args += "method=" + fetcher.location
+            args += "%s=%s" % (self.method_arg, fetcher.location)
 
         if guest.extraargs:
             args += " " + guest.extraargs
@@ -492,11 +493,17 @@ class FedoraDistro(RedHatDistro):
             ret = (m != None)
 
             if ret:
+                lateststr, latestnum = self._latestFedoraVariant()
                 ver = self.treeinfo.get("general", "version")
                 if ver == "development":
                     self.os_variant = self._latestFedoraVariant()
                 elif ver:
-                    self.os_variant = "fedora" + (str(ver).split("-"))[0]
+                    vernum = int(str(ver).split("-")[0])
+                    if vernum > latestnum:
+                        self.os_variant = lateststr
+                    else:
+                        self.os_variant = "fedora" + str(vernum)
+
 
             return ret
         else:
@@ -509,9 +516,11 @@ class FedoraDistro(RedHatDistro):
         ret = None
         for var in osdict.sort_helper(osdict.OS_TYPES["linux"]["variants"]):
             if var.startswith("fedora"):
-                # Last fedora* occurence should be the newest
+                # First fedora* occurence should be the newest
                 ret = var
-        return ret
+                break
+
+        return ret, int(ret[6:])
 
 # Red Hat Enterprise Linux distro check
 class RHELDistro(RedHatDistro):
@@ -655,6 +664,7 @@ class SuseDistro(Distro):
 
     name = "SUSE"
     os_type = "linux"
+    method_arg = "install"
     _boot_iso_paths   = [ "boot/boot.iso" ]
 
     def __init__(self, uri, arch, vmtype=None, scratchdir=None):
@@ -889,16 +899,16 @@ class SuseDistro(Distro):
 
 class DebianDistro(Distro):
     # ex. http://ftp.egr.msu.edu/debian/dists/sarge/main/installer-i386/
-    # daily builds: http://people.debian.org/~joeyh/d-i/
+    # daily builds: http://d-i.debian.org/daily-images/amd64/
 
     name = "Debian"
     os_type = "linux"
 
     def __init__(self, uri, arch, vmtype=None, scratchdir=None):
         Distro.__init__(self, uri, arch, vmtype, scratchdir)
-        if uri.count("installer-i386"):
+        if uri.count("i386"):
             self._treeArch = "i386"
-        elif uri.count("installer-amd64"):
+        elif uri.count("amd64"):
             self._treeArch = "amd64"
         else:
             self._treeArch = "i386"
@@ -925,9 +935,9 @@ class DebianDistro(Distro):
         if fetcher.hasFile("%s/MANIFEST" % self._prefix):
             # For regular trees
             pass
-        elif fetcher.hasFile("images/daily/MANIFEST"):
+        elif fetcher.hasFile("daily/MANIFEST"):
             # For daily trees
-            self._prefix = "images/daily"
+            self._prefix = "daily"
             self._set_media_paths()
         else:
             return False
