@@ -45,18 +45,20 @@ General workflow for the different storage objects:
 @see: U{http://libvirt.org/storage.html}
 """
 
-import libvirt
+import os
 import threading
 import time
-import os
-
 import logging
-from _util import xml_escape as escape
 
+import libvirt
+import urlgrabber
+
+from _util import xml_escape as escape
 import _util
 import support
 from virtinst import _gettext as _
 
+
 DEFAULT_DEV_TARGET = "/dev"
 DEFAULT_LVM_TARGET_BASE = "/dev/"
 DEFAULT_DIR_TARGET_BASE = "/var/lib/libvirt/images/"
@@ -235,6 +237,7 @@ class StoragePool(StorageObject):
     Base class for building and installing libvirt storage pool xml
     """
 
+    """@group Types: TYPE_*"""
     TYPE_DIR     = "dir"
     TYPE_FS      = "fs"
     TYPE_NETFS   = "netfs"
@@ -243,7 +246,6 @@ class StoragePool(StorageObject):
     TYPE_ISCSI   = "iscsi"
     TYPE_SCSI    = "scsi"
     TYPE_MPATH   = "mpath"
-    """@group Types: TYPE_*"""
 
     # Pool type descriptions for use in higher level programs
     _types = {}
@@ -261,7 +263,7 @@ class StoragePool(StorageObject):
         Return class associated with passed pool type.
 
         @param ptype: Pool type
-        @type ptype: C{str} member of L{Types}
+        @type ptype: member of I{Types}
         """
         if ptype not in StoragePool._types:
             raise ValueError(_("Unknown storage pool type: %s" % ptype))
@@ -309,7 +311,7 @@ class StoragePool(StorageObject):
 
         @param conn: Libvirt connection
         @param name: Name for the new pool
-        @param pool_type: Pool type string from L{Types}
+        @param pool_type: Pool type string from I{Types}
         @param host: Option host string to poll for sources
         """
         if not support.check_conn_support(conn,
@@ -449,6 +451,9 @@ class StoragePool(StorageObject):
         logging.debug("Creating storage pool '%s' with xml:\n%s",
                       self.name, xml)
 
+        if not meter:
+            meter = urlgrabber.progress.BaseMeter()
+
         try:
             pool = self.conn.storagePoolDefineXML(xml, 0)
         except Exception, e:
@@ -456,16 +461,10 @@ class StoragePool(StorageObject):
 
         errmsg = None
         if build:
-            if meter:
-                #meter.start(size=None, text=_("Creating storage pool..."))
-                pass
             try:
                 pool.build(libvirt.VIR_STORAGE_POOL_BUILD_NEW)
             except Exception, e:
                 errmsg = _("Could not build storage pool: %s" % str(e))
-            if meter:
-                #meter.end(0)
-                pass
 
         if create and not errmsg:
             try:
@@ -741,7 +740,7 @@ class LogicalPool(StoragePool):
             raise ValueError(_("Must explicitly specify source path if "
                                "building pool"))
         return StoragePool.install(self, meter=meter, create=create,
-                                   build=build, autostart=False)
+                                   build=build, autostart=autostart)
 
 class DiskPool(StoragePool):
     """
@@ -1008,7 +1007,7 @@ class StorageVolume(StorageObject):
     get_volume_for_pool = staticmethod(get_volume_for_pool)
 
     def find_free_name(name, pool_object=None, pool_name=None, conn=None,
-                       suffix="", collidelist=None):
+                       suffix="", collidelist=None, start_num=0):
         """
         Finds a name similar (or equal) to passed 'name' that is not in use
         by another pool
@@ -1022,7 +1021,8 @@ class StorageVolume(StorageObject):
 
         Ex name="test", suffix=".img" -> name-3.img
 
-        @collidelist: An extra list of names to check for collision
+        @param collidelist: An extra list of names to check for collision
+        @type collidelist: C{list}
         @returns: A free name
         @rtype: C{str}
         """
@@ -1034,7 +1034,8 @@ class StorageVolume(StorageObject):
         pool_object.refresh(0)
 
         return _util.generate_name(name, pool_object.storageVolLookupByName,
-                                   suffix, collidelist=collidelist)
+                                   suffix, collidelist=collidelist,
+                                   start_num=start_num)
     find_free_name = staticmethod(find_free_name)
 
     def lookup_pool_by_name(pool_object=None, pool_name=None, conn=None):
@@ -1199,21 +1200,22 @@ class StorageVolume(StorageObject):
                              args=(meter,))
         t.setDaemon(True)
 
+        if not meter:
+            meter = urlgrabber.progress.BaseMeter()
+
         try:
             try:
                 self._install_finished = False
                 t.start()
-                if meter:
-                    meter.start(size=self.capacity,
-                                text=_("Allocating '%s'") % self.name)
+                meter.start(size=self.capacity,
+                            text=_("Allocating '%s'") % self.name)
 
                 if self.input_vol:
                     vol = self.pool.createXMLFrom(xml, self.input_vol, 0)
                 else:
                     vol = self.pool.createXML(xml, 0)
 
-                if meter:
-                    meter.end(self.capacity)
+                meter.end(self.capacity)
                 logging.debug("Storage volume '%s' install complete.",
                               self.name)
                 return vol
