@@ -1,7 +1,7 @@
 #
 # Classes for building disk device xml
 #
-# Copyright 2006-2008  Red Hat, Inc.
+# Copyright 2006-2008, 2012  Red Hat, Inc.
 # Jeremy Katz <katzj@redhat.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -209,7 +209,7 @@ def _check_if_path_managed(conn, path):
             pool = trypool
 
     if not vol and not pool:
-        if not _util.is_uri_remote(conn.getURI()):
+        if not _util.is_uri_remote(conn.getURI(), conn=conn):
             # Building local disk
             return None, None, False
 
@@ -307,9 +307,10 @@ class VirtualDisk(VirtualDevice):
         CACHE_MODE_WRITEBACK]
 
     DEVICE_DISK = "disk"
+    DEVICE_LUN = "lun"
     DEVICE_CDROM = "cdrom"
     DEVICE_FLOPPY = "floppy"
-    devices = [DEVICE_DISK, DEVICE_CDROM, DEVICE_FLOPPY]
+    devices = [DEVICE_DISK, DEVICE_LUN, DEVICE_CDROM, DEVICE_FLOPPY]
 
     TYPE_FILE = "file"
     TYPE_BLOCK = "block"
@@ -355,7 +356,7 @@ class VirtualDisk(VirtualDevice):
         """
         Check if path exists. If we can't determine, return False
         """
-        is_remote = _util.is_uri_remote(conn.getURI())
+        is_remote = _util.is_uri_remote(conn.getURI(), conn=conn)
         try:
             vol = None
             path_is_pool = False
@@ -383,7 +384,9 @@ class VirtualDisk(VirtualDevice):
         @return: List of the directories the user cannot search, or empty list
         @rtype : C{list}
         """
-        if _util.is_uri_remote(conn.getURI()):
+        if path is None:
+            return []
+        if _util.is_uri_remote(conn.getURI(), conn=conn):
             return []
 
         try:
@@ -515,7 +518,7 @@ class VirtualDisk(VirtualDevice):
 
         @return: tuple of
                  (True if regular file, False otherwise, default is True,
-                  max size of storage, default is 0)
+                 max size of storage, default is 0)
         """
         try:
             return _util.stat_disk(path)
@@ -624,6 +627,12 @@ class VirtualDisk(VirtualDevice):
         self._error_policy = None
         self._serial = None
         self._target = None
+        self._iotune_read_bytes_sec = None
+        self._iotune_read_iops_sec = None
+        self._iotune_total_bytes_sec = None
+        self._iotune_total_iops_sec = None
+        self._iotune_write_bytes_sec = None
+        self._iotune_write_iops_sec = None
         self._validate = validate
 
         # XXX: No property methods for these
@@ -898,6 +907,84 @@ class VirtualDisk(VirtualDevice):
                                 self.serial)
     serial = _xml_property(_get_serial, _set_serial,
                            xpath="./serial")
+    
+    def _get_iotune_read_bytes_sec(self):
+        return self._iotune_read_bytes_sec
+    def _set_iotune_read_bytes_sec(self, val):
+        if (type(val) is not type(1) or val < 0):
+            raise ValueError(_("IOTune read bytes per second value must be an "
+                               "integer"))
+        self._iotune_read_bytes_sec = val
+    iotune_read_bytes_sec = _xml_property(_get_iotune_read_bytes_sec,
+                                          _set_iotune_read_bytes_sec,
+                                          xpath="./iotune/read_bytes_sec",
+                                          get_converter=lambda s, x: int(x or 0),
+                                          set_converter=lambda s, x: int(x))
+    
+    def _get_iotune_read_iops_sec(self):
+        return self._iotune_read_iops_sec
+    def _set_iotune_read_iops_sec(self, val):
+        if (type(val) is not type(1) or val < 0):
+            raise ValueError(_("IOTune read iops per second value must be an "
+                               "integer"))
+        self._iotune_read_iops_sec = val
+    iotune_read_iops_sec = _xml_property(_get_iotune_read_iops_sec,
+                                         _set_iotune_read_iops_sec,
+                                         xpath="./iotune/read_iops_sec",
+                                         get_converter=lambda s, x: int(x or 0),
+                                         set_converter=lambda s, x: int(x))
+    
+    def _get_iotune_total_bytes_sec(self):
+        return self._iotune_total_bytes_sec
+    def _set_iotune_total_bytes_sec(self, val):
+        if (type(val) is not type(1) or val < 0):
+            raise ValueError(_("IOTune total bytes per second value must be an "
+                               "integer"))
+        self._iotune_total_bytes_sec = val
+    iotune_total_bytes_sec = _xml_property(_get_iotune_total_bytes_sec,
+                                           _set_iotune_total_bytes_sec,
+                                           xpath="./iotune/total_bytes_sec",
+                                           get_converter=lambda s, x: int(x or 0),
+                                           set_converter=lambda s, x: int(x))
+    
+    def _get_iotune_total_iops_sec(self):
+        return self._iotune_total_iops_sec
+    def _set_iotune_total_iops_sec(self, val):
+        if (type(val) is not type(1) or val < 0):
+            raise ValueError(_("IOTune total iops per second value must be an "
+                               "integer"))
+        self._iotune_total_iops_sec = val
+    iotune_total_iops_sec = _xml_property(_get_iotune_total_iops_sec,
+                                          _set_iotune_total_iops_sec,
+                                          xpath="./iotune/total_iops_sec",
+                                          get_converter=lambda s, x: int(x or 0),
+                                          set_converter=lambda s, x: int(x))
+    
+    def _get_iotune_write_bytes_sec(self):
+        return self._iotune_write_bytes_sec
+    def _set_iotune_write_bytes_sec(self, val):
+        if (type(val) is not type(1) or val < 0):
+            raise ValueError(_("IOTune write bytes per second value must be an "
+                               "integer"))
+        self._iotune_write_bytes_sec = val
+    iotune_write_bytes_sec = _xml_property(_get_iotune_write_bytes_sec,
+                                           _set_iotune_write_bytes_sec,
+                                           xpath="./iotune/write_bytes_sec",
+                                           get_converter=lambda s, x: int(x or 0),
+                                           set_converter=lambda s, x: int(x))
+    
+    def _get_iotune_write_iops_sec(self):
+        return self._iotune_write_iops_sec
+    def _set_iotune_write_iops_sec(self, val):
+        if (type(val) is not type(1) or val < 0):
+            raise ValueError(_("IOTune write iops per second value must be an "
+                               "integer"))
+        self._iotune_write_iops_sec = val
+    iotune_write_iops_sec = _xml_property(_get_iotune_write_iops_sec,
+                                          _set_iotune_write_iops_sec,
+                                          xpath="./iotune/write_iops_sec",
+                                          get_converter=lambda s, x: int(x or 0),
+                                          set_converter=lambda s, x: int(x))
 
     # If there is no selinux support on the libvirt connection or the
     # system, we won't throw errors if this is set, just silently ignore.
@@ -1533,6 +1620,24 @@ class VirtualDisk(VirtualDevice):
         if self.serial:
             ret += ("      <serial>%s</serial>\n" %
                     _util.xml_escape(self.serial))
+        
+        if (self.iotune_read_bytes_sec or self.iotune_read_iops_sec or
+            self.iotune_total_bytes_sec or self.iotune_total_iops_sec or
+            self.iotune_write_bytes_sec or self.iotune_write_iops_sec):
+            ret += "      <iotune>"
+            if self.iotune_read_bytes_sec:
+                ret += "        <read_bytes_sec>%s</read_bytes_sec>" % (self.iotune_read_bytes_sec)
+            if self.iotune_read_iops_sec:
+                ret += "        <read_iops_sec>%s</read_iops_sec>" % (self.iotune_read_iops_sec)
+            if self.iotune_total_bytes_sec:
+                ret += "        <total_bytes_sec>%s</total_bytes_sec>" % (self.iotune_total_bytes_sec)
+            if self.iotune_total_iops_sec:
+                ret += "        <total_iops_sec>%s</total_iops_sec>" % (self.iotune_total_iops_sec)
+            if self.iotune_write_bytes_sec:
+                ret += "        <write_bytes_sec>%s</write_bytes_sec>" % (self.iotune_write_bytes_sec)
+            if self.iotune_write_iops_sec:
+                ret += "        <write_iops_sec>%s</write_iops_sec>" % (self.iotune_write_iops_sec)
+            ret += "      </iotune>"
 
         ret += "    </disk>"
         return ret
@@ -1618,11 +1723,10 @@ class VirtualDisk(VirtualDevice):
         for selinux commands
         """
         caps = self._get_caps()
-        if (not caps and False):
-            #caps.host.secmodel is None or
-            #caps.host.secmodel.model != "selinux"):
-            # XXX: Libvirt support isn't strictly required, but all the
-            #      our label guesses are built with svirt in mind
+        if not caps:
+            return False
+
+        elif "selinux" not in [x.model for x in caps.host.secmodels]:
             return False
 
         elif self.is_remote():
@@ -1710,10 +1814,11 @@ class VirtualDisk(VirtualDevice):
     def generate_target(self, skip_targets):
         """
         Generate target device ('hda', 'sdb', etc..) for disk, excluding
-        any targets in list 'skip_targets'. Sets self.target, and returns the
+        any targets in 'skip_targets'. Sets self.target, and returns the
         generated value
-        @param used_targets: list of targets to exclude
-        @type used_targets: C{list}
+
+        @param skip_targets: list of targets to exclude
+        @type skip_targets: C{list}
         @raise ValueError: can't determine target type, no targets available
         @returns generated target
         @rtype C{str}
