@@ -172,7 +172,8 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
         if self.conn and not self._random_mac:
             found = False
             for ignore in range(256):
-                self._random_mac = _util.randomMAC(self.conn.getType().lower())
+                self._random_mac = _util.randomMAC(self.conn.getType().lower(),
+                                                   conn=self.conn)
                 ret = self.is_conflict_net(self.conn, self._random_mac)
                 if ret[1] is not None:
                     continue
@@ -301,31 +302,28 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
 
     def is_conflict_net(self, conn, mac=None):
         """
-        is_conflict_net: determines if mac conflicts with others in system
-
-        returns a two element tuple:
+        @returns: a two element tuple:
             first element is True if fatal collision occured
             second element is a string description of the collision.
 
-        Non fatal collisions (mac addr collides with inactive guest) will
-        return (False, "description of collision")
+            Non fatal collisions (mac addr collides with inactive guest) will
+            return (False, "description of collision")
         """
         mac = mac or self.macaddr
         if mac is None:
             return (False, None)
 
-        # Not supported for remote connections yet
-        if self.is_remote():
-            return (False, None)
-
         vms, inactive_vm = _util.fetch_all_guests(conn)
 
-        # get the Host's NIC MACaddress
-        hostdevs = _util.get_host_network_devices()
+        # get the Host's NIC MAC address
+        hostdevs = []
+        if not self.is_remote():
+            hostdevs = _util.get_host_network_devices()
 
-        if _countMACaddr(vms, mac) > 0:
+        if (_countMACaddr(vms, mac) > 0 or
+            _countMACaddr(inactive_vm, mac) > 0):
             return (True, _("The MAC address you entered is already in use "
-                            "by another active virtual machine."))
+                            "by another virtual machine."))
 
         for dev in hostdevs:
             host_macaddr = dev[4]
@@ -333,10 +331,6 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
                 return (True, _("The MAC address you entered conflicts with "
                                 "a device on the physical host."))
 
-        if _countMACaddr(inactive_vm, mac) > 0:
-            return (False, _("The MAC address you entered is already in use "
-                             "by another inactive virtual machine."))
-
         return (False, None)
 
     def setup_dev(self, conn=None, meter=None):
@@ -364,6 +358,7 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
         src_xml = ""
         model_xml = ""
         target_xml = ""
+        addr_xml = ""
         if self.type == self.TYPE_BRIDGE:
             src_xml     = "      <source bridge='%s'/>\n" % self.bridge
         elif self.type == self.TYPE_VIRTUAL:
@@ -376,6 +371,9 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
         if self.model:
             model_xml   = "      <model type='%s'/>\n" % self.model
 
+        if self.address:
+            addr_xml = self.indent(self.address.get_xml_config(), 6)
+
         if self.target_dev:
             target_xml  = "      <target dev='%s'/>\n" % self.target_dev
 
@@ -384,6 +382,7 @@ class VirtualNetworkInterface(VirtualDevice.VirtualDevice):
         xml += "      <mac address='%s'/>\n" % self.macaddr
         xml += target_xml
         xml += model_xml
+        xml += addr_xml
         xml += "    </interface>"
         return xml
 
