@@ -18,6 +18,7 @@
 # MA 02110-1301 USA.
 
 import VirtualDevice
+from XMLBuilderDomain import _xml_property
 
 class VirtualVideoDevice(VirtualDevice.VirtualDevice):
 
@@ -25,15 +26,27 @@ class VirtualVideoDevice(VirtualDevice.VirtualDevice):
 
     # Default models list
     MODEL_DEFAULT = "default"
-    _model_types = [ "cirrus", "vga", "vmvga", "xen", MODEL_DEFAULT]
+    _model_types = [ "cirrus", "vga", "vmvga", "xen", "qxl", MODEL_DEFAULT]
 
-    def __init__(self, conn):
-        VirtualDevice.VirtualDevice.__init__(self, conn=conn)
+    @staticmethod
+    def pretty_model(model):
+        if model in ["qxl", "vmvga"]:
+            return model.upper()
+        return model.capitalize()
 
-        self._model_type    = self.MODEL_DEFAULT
+    def __init__(self, conn, parsexml=None, parsexmlnode=None, caps=None):
+        VirtualDevice.VirtualDevice.__init__(self, conn,
+                                             parsexml, parsexmlnode, caps)
+
+        self._model_type    = None
         self._vram          = None
         self._heads         = None
 
+        if self._is_parse():
+            return
+
+        self.model_type = self.MODEL_DEFAULT
+
     def get_model_types(self):
         return self._model_types[:]
     model_types = property(get_model_types)
@@ -42,21 +55,24 @@ class VirtualVideoDevice(VirtualDevice.VirtualDevice):
         return self._model_type
     def set_model_type(self, val):
         self._model_type = val
-    model_type = property(get_model_type, set_model_type)
+    model_type = _xml_property(get_model_type, set_model_type,
+                               xpath="./model/@type")
 
     def get_vram(self):
         return self._vram
     def set_vram(self, val):
         self._vram = val
-    vram = property(get_vram, set_vram)
+    vram = _xml_property(get_vram, set_vram,
+                         xpath="./model/@vram")
 
     def get_heads(self):
         return self._heads
     def set_heads(self, val):
         self._heads = val
-    heads = property(get_heads, set_heads)
+    heads = _xml_property(get_heads, set_heads,
+                          xpath="./model/@heads")
 
-    def get_xml_config(self):
+    def _get_xml_config(self):
         model = self.model_type
         if self.model_type == self.MODEL_DEFAULT:
             model = "cirrus"
