@@ -1,7 +1,7 @@
 #
 # Utility functions for the command line drivers
 #
-# Copyright 2006-2007  Red Hat, Inc.
+# Copyright 2006-2007, 2013  Red Hat, Inc.
 # Jeremy Katz <katzj@redhat.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@ import difflib
 import tempfile
 import optparse
 import shlex
+import itertools
 
 import libvirt
 
@@ -144,7 +145,13 @@ def setupParser(usage=None):
     return parser
 
 def setupGettext():
-    locale.setlocale(locale.LC_ALL, '')
+    try:
+        locale.setlocale(locale.LC_ALL, '')
+    except locale.Error, e:
+        print >> sys.stderr, "warning: failed to set locale, defaulting to C"
+        os.environ['LC_ALL'] = 'C'
+        locale.setlocale(locale.LC_ALL, 'C')
+
     gettext.bindtextdomain("virtinst")
     gettext.install("virtinst")
 
@@ -822,7 +829,7 @@ def get_vcpus(guest, vcpus, check_cpu, image_vcpus=None):
             if not prompt_for_yes_or_no(msg, askmsg):
                 nice_exit()
 
-def get_cpuset(guest, cpuset):
+def get_cpuset(guest, cpuset, memory):
     conn = guest.conn
     if cpuset and cpuset != "auto":
         guest.cpuset = cpuset
@@ -830,7 +837,7 @@ def get_cpuset(guest, cpuset):
     elif cpuset == "auto":
         tmpset = None
         try:
-            tmpset = Guest.generate_cpuset(conn, guest.memory)
+            tmpset = Guest.generate_cpuset(conn, memory)
         except Exception, e:
             logging.debug("Not setting cpuset: %s", str(e))
 
@@ -1126,7 +1133,7 @@ def add_device_options(devg):
                            "--redirdev usb,type=tcp,server=192.168.1.1:4000"))
     devg.add_option("", "--memballoon", dest="memballoon", action="append",
                     help=_("Configure a guest memballoon device. Ex:\n"
-                           "--memballoon medel=virtio"))
+                           "--memballoon model=virtio"))
 
 def add_gfx_option(devg):
     devg.add_option("", "--graphics", dest="graphics", action="append",
@@ -1179,6 +1186,7 @@ def parse_optstr_tuples(optstr, compress_first=False):
         return [(optstr, None)]
 
     argsplitter = shlex.shlex(optstr, posix=True)
+    argsplitter.commenters = ""
     argsplitter.whitespace = ","
     argsplitter.whitespace_split = True
 
@@ -1210,8 +1218,7 @@ def parse_optstr(optstr, basedict=None, remove_first=None,
                          returns {"char_type", "pty", "foo" : "bar"}
     @param compress_first: If there are no options of the form opt1=opt2,
                            compress the string to a single option
-
-    Returns a dictionary of {'opt1': 'val1', 'opt2': 'val2'}
+    @returns: a dictionary of {'opt1': 'val1', 'opt2': 'val2'}
     """
     optlist = parse_optstr_tuples(optstr, compress_first=compress_first)
     optdict = basedict or {}
@@ -1477,6 +1484,8 @@ def parse_security(guest, security):
 # --disk parsing #
 ##################
 
+_disk_counter = itertools.count()
+
 def _parse_disk_source(guest, path, pool, vol, size, fmt, sparse):
     abspath = None
     volinst = None
@@ -1499,9 +1508,10 @@ def _parse_disk_source(guest, path, pool, vol, size, fmt, sparse):
         vc = virtinst.Storage.StorageVolume.get_volume_for_pool(pool_name=pool,
                                                                 conn=guest.conn)
         vname = virtinst.Storage.StorageVolume.find_free_name(conn=guest.conn,
-                                                              pool_name=pool,
-                                                              name=guest.name,
-                                                              suffix=".img")
+                                            pool_name=pool,
+                                            name=guest.name,
+                                            suffix=".img",
+                                            start_num=_disk_counter.next())
         volinst = vc(pool_name=pool, name=vname, conn=guest.conn,
                      allocation=0, capacity=(size and
                                              size * 1024 * 1024 * 1024))
@@ -1605,6 +1615,7 @@ def parse_disk(guest, optstr, dev=None):
                                    volInstall=volinst,
                                    size=size,
                                    readOnly=ro,
+                                   sparse=sparse,
                                    shareable=shared,
                                    device=device,
                                    format=fmt)
@@ -1739,6 +1750,10 @@ def parse_controller(guest, optstring, dev=None):
     if optstring is None:
         return None
 
+    if optstring == "usb2":
+        guest.add_usb_ich9_controllers()
+        return None
+
     # Peel the mode off the front
     opts = parse_optstr(optstring, remove_first="type")
     ctrltype = get_opt_param(opts, "type")
