@@ -267,6 +267,16 @@ OS_TYPES = {
             INPUT: USB_TABLET,
         }
     },
+    "rhel7": {
+        "label": "Red Hat Enterprise Linux 7",
+        "distro": "rhel",
+        "supported": False,
+        "devices" : {
+            DISK : VIRTIO_DISK,
+            NET  : VIRTIO_NET,
+            INPUT: USB_TABLET,
+        }
+    },
 
     "fedora5": {
         "sortby": "fedora05",
@@ -336,7 +346,6 @@ OS_TYPES = {
     "fedora14": {
         "label": "Fedora 14",
         "distro": "fedora",
-        "supported": True,
         "devices" : {
             DISK : VIRTIO_DISK,
             NET  : VIRTIO_NET,
@@ -363,6 +372,26 @@ OS_TYPES = {
             INPUT: USB_TABLET,
         }
     },
+    "fedora17": {
+        "label": "Fedora 17",
+        "distro": "fedora",
+        "supported": True,
+        "devices" : {
+            DISK : VIRTIO_DISK,
+            NET  : VIRTIO_NET,
+            INPUT: USB_TABLET,
+        }
+    },
+    "fedora18": {
+        "label": "Fedora 18",
+        "distro": "fedora",
+        "supported": True,
+        "devices" : {
+            DISK : VIRTIO_DISK,
+            NET  : VIRTIO_NET,
+            INPUT: USB_TABLET,
+        }
+    },
 
     "opensuse11": {
         "label": "openSuse 11",
@@ -405,7 +434,6 @@ OS_TYPES = {
     "mandriva2010": {
         "label": "Mandriva Linux 2010 and later",
         "distro": "mandriva",
-        "supported": True,
         "devices" : {
             DISK : VIRTIO_DISK,
             NET  : VIRTIO_NET,
@@ -508,7 +536,7 @@ OS_TYPES = {
         },
     },
     "ubuntulucid": {
-        "label": "Ubuntu 10.04 (Lucid Lynx)",
+        "label": "Ubuntu 10.04 LTS (Lucid Lynx)",
         "distro": "ubuntu",
         "supported": True,
         "devices" : {
@@ -519,7 +547,6 @@ OS_TYPES = {
     "ubuntumaverick": {
         "label": "Ubuntu 10.10 (Maverick Meerkat)",
         "distro": "ubuntu",
-        "supported": True,
         "devices" : {
             DISK : VIRTIO_DISK,
             NET  : VIRTIO_NET,
@@ -543,6 +570,24 @@ OS_TYPES = {
             NET  : VIRTIO_NET,
         },
     },
+    "ubuntuprecise": {
+        "label": "Ubuntu 12.04 LTS (Precise Pangolin)",
+        "distro": "ubuntu",
+        "supported": True,
+        "devices" : {
+            DISK : VIRTIO_DISK,
+            NET  : VIRTIO_NET,
+        },
+    },
+    "ubuntuquantal": {
+        "label": "Ubuntu 12.10 (Quantal Quetzal)",
+        "distro": "ubuntu",
+        "supported": True,
+        "devices" : {
+            DISK : VIRTIO_DISK,
+            NET  : VIRTIO_NET,
+        },
+    },
 
     "generic24": {
         "label": "Generic 2.4.x kernel"
